# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`nservicebusservicecontrol`](#nservicebusservicecontrol): Installs and configures Particular's Service Control Monitoring Tool.

#### Private Classes

* `nservicebusservicecontrol::config`: This class handles the configuration of servicecontrol.
* `nservicebusservicecontrol::install`: This class handles the management of the servicecontrol installer and package.

### Defined types

* [`nservicebusservicecontrol::audit_instance`](#nservicebusservicecontrolaudit_instance): Manages Service Control Instances.
* [`nservicebusservicecontrol::instance`](#nservicebusservicecontrolinstance): Manages Service Control Instances.
* [`nservicebusservicecontrol::monitoring_instance`](#nservicebusservicecontrolmonitoring_instance): Manages Service Control Monitoring Instances.

### Data types

* [`Nservicebusservicecontrol::Log_level`](#nservicebusservicecontrollog_level)
* [`Nservicebusservicecontrol::Transport`](#nservicebusservicecontroltransport): https://github.com/Particular/ServiceControl/blob/develop/src/ServiceControlInstaller.Engine/Instances/TransportNames.cs

### Tasks

* [`get_instances`](#get_instances): Gets all servicecontrol instances.

### Plans

* [`nservicebusservicecontrol::compact_database`](#nservicebusservicecontrolcompact_database): Compacts the servicecontrol instance's RavenDB Database.
* [`nservicebusservicecontrol::import_failed_messages`](#nservicebusservicecontrolimport_failed_messages): Imports failed error or audit messages.

## Classes

### <a name="nservicebusservicecontrol"></a>`nservicebusservicecontrol`

Installs and configures Particular's Service Control Monitoring Tool.

#### Parameters

The following parameters are available in the `nservicebusservicecontrol` class:

* [`package_ensure`](#package_ensure)
* [`package_source`](#package_source)
* [`license_xml`](#license_xml)

##### <a name="package_ensure"></a>`package_ensure`

Data type: `String`

Whether to install the ServiceControl package.

Default value: `'present'`

##### <a name="package_source"></a>`package_source`

Data type: `Optional[String]`

The package source for the package.

Default value: ``undef``

##### <a name="license_xml"></a>`license_xml`

Data type: `Optional[String]`

A valid NServiceBus XML License.

Default value: `''`

## Defined types

### <a name="nservicebusservicecontrolaudit_instance"></a>`nservicebusservicecontrol::audit_instance`

Manages Service Control Instances.

#### Parameters

The following parameters are available in the `nservicebusservicecontrol::audit_instance` defined type:

* [`ensure`](#ensure)
* [`service_control_queue_address`](#service_control_queue_address)
* [`instance_name`](#instance_name)
* [`install_path`](#install_path)
* [`log_path`](#log_path)
* [`db_path`](#db_path)
* [`db_index_storage_path`](#db_index_storage_path)
* [`db_logs_path`](#db_logs_path)
* [`instance_log_level`](#instance_log_level)
* [`host_name`](#host_name)
* [`port`](#port)
* [`database_maintenance_port`](#database_maintenance_port)
* [`expose_ravendb`](#expose_ravendb)
* [`ravendb_log_level`](#ravendb_log_level)
* [`transport`](#transport)
* [`display_name`](#display_name)
* [`connection_string`](#connection_string)
* [`description`](#description)
* [`service_account`](#service_account)
* [`service_account_password`](#service_account_password)
* [`service_restart_on_config_change`](#service_restart_on_config_change)
* [`audit_retention_period`](#audit_retention_period)
* [`time_to_restart_audit_ingestion_after_failure`](#time_to_restart_audit_ingestion_after_failure)
* [`enable_full_text_search_on_bodies`](#enable_full_text_search_on_bodies)
* [`expiration_process_timer_in_seconds`](#expiration_process_timer_in_seconds)
* [`expiration_process_batch_size`](#expiration_process_batch_size)
* [`data_space_remaining_threshold`](#data_space_remaining_threshold)
* [`max_body_size_to_store`](#max_body_size_to_store)
* [`http_default_connection_limit`](#http_default_connection_limit)
* [`service_manage`](#service_manage)
* [`skip_queue_creation`](#skip_queue_creation)
* [`remove_db_on_delete`](#remove_db_on_delete)
* [`remove_logs_on_delete`](#remove_logs_on_delete)
* [`automatic_instance_upgrades`](#automatic_instance_upgrades)
* [`audit_queue`](#audit_queue)
* [`audit_log_queue`](#audit_log_queue)
* [`forward_audit_messages`](#forward_audit_messages)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Specifies whether the instance should exist.

##### <a name="service_control_queue_address"></a>`service_control_queue_address`

Data type: `String`

The ServiceControl queue name to use for plugin messages (e.g. Heartbeats, Custom Checks, Saga Audit, etc ).

##### <a name="instance_name"></a>`instance_name`

Data type: `String`

Specify the name of the ServiceControl Instance (title).

Default value: `$title`

##### <a name="install_path"></a>`install_path`

Data type: `Stdlib::Absolutepath`

Specify the directory to use for this ServiceControl Instance.

Default value: `"C:\\Program Files (x86)\\Particular Software\\${instance_name}"`

##### <a name="log_path"></a>`log_path`

Data type: `Stdlib::Absolutepath`

Specify the directory to use for this ServiceControl Logs.

Default value: `"C:\\ProgramData\\Particular\\ServiceControl\\${instance_name}\\Logs"`

##### <a name="db_path"></a>`db_path`

Data type: `Stdlib::Absolutepath`

Specify the directory that will contain the nservicebusservicecontrol database for this ServiceControl Instance.

Default value: `"C:\\ProgramData\\Particular\\ServiceControl\\${instance_name}\\DB"`

##### <a name="db_index_storage_path"></a>`db_index_storage_path`

Data type: `Stdlib::Absolutepath`

Specify the path for the indexes on disk.

Default value: `"${db_path}\\Indexes"`

##### <a name="db_logs_path"></a>`db_logs_path`

Data type: `Stdlib::Absolutepath`

Specify the path for the Esent logs on disk.

Default value: `"${db_path}\\logs"`

##### <a name="instance_log_level"></a>`instance_log_level`

Data type: `Nservicebusservicecontrol::Log_level`

Specify the level of logging that should be used in ServiceControl logs.

Default value: `'Warn'`

##### <a name="host_name"></a>`host_name`

Data type: `Stdlib::Fqdn`

Specify the hostname to use in the URLACL.

Default value: `'localhost'`

##### <a name="port"></a>`port`

Data type: `Stdlib::Port`

Specify the port number to listen on. If this is the only ServiceControl instance then 44444 is recommended.

Default value: `44444`

##### <a name="database_maintenance_port"></a>`database_maintenance_port`

Data type: `Stdlib::Port`

Specify the database maintenance port number to listen on. If this is the only ServiceControl instance then 44445 is recommended.

Default value: `44445`

##### <a name="expose_ravendb"></a>`expose_ravendb`

Data type: `Boolean`

Specify if the embedded ravendb database should be accessible outside of maintenance mode.

Default value: ``false``

##### <a name="ravendb_log_level"></a>`ravendb_log_level`

Data type: `Nservicebusservicecontrol::Log_level`

Specify the level of logging that should be used in ravendb logs.

Default value: `'Warn'`

##### <a name="transport"></a>`transport`

Data type: `Nservicebusservicecontrol::Transport`

Specify the NServiceBus Transport to use.

Default value: `'MSMQ'`

##### <a name="display_name"></a>`display_name`

Data type: `String`

Specify the Windows Service Display name. If unspecified the instance name will be used.

Default value: `$instance_name`

##### <a name="connection_string"></a>`connection_string`

Data type: `Optional[String]`

Specify the connection string to use to connect to the queuing system.

Default value: ``undef``

##### <a name="description"></a>`description`

Data type: `String`

Specify the description to use on the Windows Service for this instance.

Default value: `'A ServiceControl Audit Instance'`

##### <a name="service_account"></a>`service_account`

Data type: `String`

The Account to run the Windows service.

Default value: `'LocalSystem'`

##### <a name="service_account_password"></a>`service_account_password`

Data type: `Optional[String]`

The password for the ServiceAccount.

Default value: ``undef``

##### <a name="service_restart_on_config_change"></a>`service_restart_on_config_change`

Data type: `Boolean`

Specify if the servicecontrol instance's windows service should be restarted to pick up changes to its configuration file.

Default value: ``true``

##### <a name="audit_retention_period"></a>`audit_retention_period`

Data type: `String`

Specify thd grace period that faulted messages are kept before they are deleted.

Default value: `'30.00:00:00'`

##### <a name="time_to_restart_audit_ingestion_after_failure"></a>`time_to_restart_audit_ingestion_after_failure`

Data type: `String`

Specify the maximum time delay to wait before restarting the audit ingestion pipeline after detecting a connection problem. This setting was introduced in ServiceControl version 4.4.1.

Default value: `'00.00:01:00'`

##### <a name="enable_full_text_search_on_bodies"></a>`enable_full_text_search_on_bodies`

Data type: `Boolean`

Allows full text searches to happen on the body of messages. This setting was introduced in ServiceControl version 4.17.0.

Default value: ``true``

##### <a name="expiration_process_timer_in_seconds"></a>`expiration_process_timer_in_seconds`

Data type: `Integer`

Specifies the number of seconds to wait between checking for expired messages.

Default value: `600`

##### <a name="expiration_process_batch_size"></a>`expiration_process_batch_size`

Data type: `Integer`

Specifies the batch size to use when checking for expired messages.

Default value: `65512`

##### <a name="data_space_remaining_threshold"></a>`data_space_remaining_threshold`

Data type: `Integer`

The percentage threshold for the Message database storage space check. If the remaining hard drive space drops below this threshold (as a percentage of the total space on the drive), then the check will fail, alerting the user.

Default value: `20`

##### <a name="max_body_size_to_store"></a>`max_body_size_to_store`

Data type: `Integer`

Specifies the upper limit on body size to be configured.

Default value: `102400`

##### <a name="http_default_connection_limit"></a>`http_default_connection_limit`

Data type: `Integer`

Specifies the maximum number of concurrent connections allowed by ServiceControl.

Default value: `100`

##### <a name="service_manage"></a>`service_manage`

Data type: `Boolean`

Specifies whether or not to manage the desired state of the windows service for this instance.

Default value: ``true``

##### <a name="skip_queue_creation"></a>`skip_queue_creation`

Data type: `Boolean`

Normally an instance will attempt to create the queues that it uses. If this flag is set, queue creation will be skipped.

Default value: ``false``

##### <a name="remove_db_on_delete"></a>`remove_db_on_delete`

Data type: `Boolean`

Remove service control instance ravendb database when instance is deleted.

Default value: ``false``

##### <a name="remove_logs_on_delete"></a>`remove_logs_on_delete`

Data type: `Boolean`

Remove service control instance logs when instance is deleted.

Default value: ``false``

##### <a name="automatic_instance_upgrades"></a>`automatic_instance_upgrades`

Data type: `Boolean`

Automatically upgrade the service control monitoring instance when a new version of servicecontrol is installed.

Default value: ``true``

##### <a name="audit_queue"></a>`audit_queue`

Data type: `String`



Default value: `'audit'`

##### <a name="audit_log_queue"></a>`audit_log_queue`

Data type: `Optional[String]`



Default value: `'audit.log'`

##### <a name="forward_audit_messages"></a>`forward_audit_messages`

Data type: `Boolean`



Default value: ``false``

### <a name="nservicebusservicecontrolinstance"></a>`nservicebusservicecontrol::instance`

Manages Service Control Instances.

#### Parameters

The following parameters are available in the `nservicebusservicecontrol::instance` defined type:

* [`ensure`](#ensure)
* [`instance_name`](#instance_name)
* [`install_path`](#install_path)
* [`log_path`](#log_path)
* [`db_path`](#db_path)
* [`db_index_storage_path`](#db_index_storage_path)
* [`db_logs_path`](#db_logs_path)
* [`instance_log_level`](#instance_log_level)
* [`host_name`](#host_name)
* [`port`](#port)
* [`database_maintenance_port`](#database_maintenance_port)
* [`remote_instances`](#remote_instances)
* [`expose_ravendb`](#expose_ravendb)
* [`ravendb_log_level`](#ravendb_log_level)
* [`error_queue`](#error_queue)
* [`error_log_queue`](#error_log_queue)
* [`transport`](#transport)
* [`display_name`](#display_name)
* [`connection_string`](#connection_string)
* [`description`](#description)
* [`forward_error_messages`](#forward_error_messages)
* [`service_account`](#service_account)
* [`service_account_password`](#service_account_password)
* [`service_restart_on_config_change`](#service_restart_on_config_change)
* [`error_retention_period`](#error_retention_period)
* [`time_to_restart_error_ingestion_after_failure`](#time_to_restart_error_ingestion_after_failure)
* [`enable_full_text_search_on_bodies`](#enable_full_text_search_on_bodies)
* [`event_retention_period`](#event_retention_period)
* [`expiration_process_timer_in_seconds`](#expiration_process_timer_in_seconds)
* [`expiration_process_batch_size`](#expiration_process_batch_size)
* [`data_space_remaining_threshold`](#data_space_remaining_threshold)
* [`http_default_connection_limit`](#http_default_connection_limit)
* [`heartbeat_grace_period`](#heartbeat_grace_period)
* [`allow_message_editing`](#allow_message_editing)
* [`service_manage`](#service_manage)
* [`skip_queue_creation`](#skip_queue_creation)
* [`remove_db_on_delete`](#remove_db_on_delete)
* [`remove_logs_on_delete`](#remove_logs_on_delete)
* [`automatic_instance_upgrades`](#automatic_instance_upgrades)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Specifies whether the instance should exist.

##### <a name="instance_name"></a>`instance_name`

Data type: `String`

Specify the name of the ServiceControl Instance (title).

Default value: `$title`

##### <a name="install_path"></a>`install_path`

Data type: `Stdlib::Absolutepath`

Specify the directory to use for this ServiceControl Instance.

Default value: `"C:\\Program Files (x86)\\Particular Software\\${instance_name}"`

##### <a name="log_path"></a>`log_path`

Data type: `Stdlib::Absolutepath`

Specify the directory to use for this ServiceControl Logs.

Default value: `"C:\\ProgramData\\Particular\\ServiceControl\\${instance_name}\\Logs"`

##### <a name="db_path"></a>`db_path`

Data type: `Stdlib::Absolutepath`

Specify the directory that will contain the nservicebusservicecontrol database for this ServiceControl Instance.

Default value: `"C:\\ProgramData\\Particular\\ServiceControl\\${instance_name}\\DB"`

##### <a name="db_index_storage_path"></a>`db_index_storage_path`

Data type: `Stdlib::Absolutepath`

Specify the path for the indexes on disk.

Default value: `"${db_path}\\Indexes"`

##### <a name="db_logs_path"></a>`db_logs_path`

Data type: `Stdlib::Absolutepath`

Specify the path for the Esent logs on disk.

Default value: `"${db_path}\\logs"`

##### <a name="instance_log_level"></a>`instance_log_level`

Data type: `Nservicebusservicecontrol::Log_level`

Specify the level of logging that should be used in ServiceControl logs.

Default value: `'Warn'`

##### <a name="host_name"></a>`host_name`

Data type: `Stdlib::Fqdn`

Specify the hostname to use in the URLACL.

Default value: `'localhost'`

##### <a name="port"></a>`port`

Data type: `Stdlib::Port`

Specify the port number to listen on. If this is the only ServiceControl instance then 33333 is recommended.

Default value: `33333`

##### <a name="database_maintenance_port"></a>`database_maintenance_port`

Data type: `Stdlib::Port`

Specify the database maintenance port number to listen on. If this is the only ServiceControl instance then 33334 is recommended.

Default value: `33334`

##### <a name="remote_instances"></a>`remote_instances`

Data type: `Optional[Array[String]]`

Specify an optional array of remote instances.

Default value: `[]`

##### <a name="expose_ravendb"></a>`expose_ravendb`

Data type: `Boolean`

Specify if the embedded ravendb database should be accessible outside of maintenance mode.

Default value: ``false``

##### <a name="ravendb_log_level"></a>`ravendb_log_level`

Data type: `Nservicebusservicecontrol::Log_level`

Specify the level of logging that should be used in ravendb logs.

Default value: `'Warn'`

##### <a name="error_queue"></a>`error_queue`

Data type: `String`

Specify ErrorQueue name to consume messages from.

Default value: `'error'`

##### <a name="error_log_queue"></a>`error_log_queue`

Data type: `Optional[String]`

Specify Queue name to forward error messages to.

Default value: `'error.log'`

##### <a name="transport"></a>`transport`

Data type: `Nservicebusservicecontrol::Transport`

Specify the NServiceBus Transport to use.

Default value: `'MSMQ'`

##### <a name="display_name"></a>`display_name`

Data type: `String`

Specify the Windows Service Display name. If unspecified the instance name will be used.

Default value: `$instance_name`

##### <a name="connection_string"></a>`connection_string`

Data type: `Optional[String]`

Specify the connection string to use to connect to the queuing system.

Default value: ``undef``

##### <a name="description"></a>`description`

Data type: `String`

Specify the description to use on the Windows Service for this instance.

Default value: `'A ServiceControl Instance'`

##### <a name="forward_error_messages"></a>`forward_error_messages`

Data type: `Boolean`

Specify if audit messages are forwarded to the queue specified by ErrorLogQueue.

Default value: ``false``

##### <a name="service_account"></a>`service_account`

Data type: `String`

The Account to run the Windows service.

Default value: `'LocalSystem'`

##### <a name="service_account_password"></a>`service_account_password`

Data type: `Optional[String]`

The password for the ServiceAccount.

Default value: ``undef``

##### <a name="service_restart_on_config_change"></a>`service_restart_on_config_change`

Data type: `Boolean`

Specify if the service control instance's windows service should be restarted to pick up changes to its configuration file.

Default value: ``true``

##### <a name="error_retention_period"></a>`error_retention_period`

Data type: `String`

Specify thd grace period that faulted messages are kept before they are deleted.

Default value: `'15.00:00:00'`

##### <a name="time_to_restart_error_ingestion_after_failure"></a>`time_to_restart_error_ingestion_after_failure`

Data type: `String`

Specify the maximum time delay to wait before restarting the error ingestion pipeline after detecting a connection problem. This setting was introduced in ServiceControl version 4.4.1.

Default value: `'00.00:01:00'`

##### <a name="enable_full_text_search_on_bodies"></a>`enable_full_text_search_on_bodies`

Data type: `Boolean`

Allows full text searches to happen on the body of messages. This setting was introduced in ServiceControl version 4.17.0.

Default value: ``true``

##### <a name="event_retention_period"></a>`event_retention_period`

Data type: `String`

Specifies the period to keep event logs before they are deleted.

Default value: `'14.00:00:00'`

##### <a name="expiration_process_timer_in_seconds"></a>`expiration_process_timer_in_seconds`

Data type: `Integer`

Specifies the number of seconds to wait between checking for expired messages.

Default value: `600`

##### <a name="expiration_process_batch_size"></a>`expiration_process_batch_size`

Data type: `Integer`

Specifies the batch size to use when checking for expired messages.

Default value: `65512`

##### <a name="data_space_remaining_threshold"></a>`data_space_remaining_threshold`

Data type: `Integer`

The percentage threshold for the Message database storage space check. If the remaining hard drive space drops below this threshold (as a percentage of the total space on the drive), then the check will fail, alerting the user.

Default value: `20`

##### <a name="http_default_connection_limit"></a>`http_default_connection_limit`

Data type: `Integer`

Specifies the maximum number of concurrent connections allowed by ServiceControl.

Default value: `100`

##### <a name="heartbeat_grace_period"></a>`heartbeat_grace_period`

Data type: `String`

Specifies the period that defines whether an endpoint is considered alive or not since the last received heartbeat.

Default value: `'00:00:40'`

##### <a name="allow_message_editing"></a>`allow_message_editing`

Data type: `Boolean`

Enables the ability for servicepulse to allow users to edit failed messages before being retried.

Default value: ``false``

##### <a name="service_manage"></a>`service_manage`

Data type: `Boolean`

Specifies whether or not to manage the desired state of the windows service for this instance.

Default value: ``true``

##### <a name="skip_queue_creation"></a>`skip_queue_creation`

Data type: `Boolean`

Normally an instance will attempt to create the queues that it uses. If this flag is set, queue creation will be skipped.

Default value: ``false``

##### <a name="remove_db_on_delete"></a>`remove_db_on_delete`

Data type: `Boolean`

Remove service control instance ravendb database when instance is deleted.

Default value: ``false``

##### <a name="remove_logs_on_delete"></a>`remove_logs_on_delete`

Data type: `Boolean`

Remove service control instance logs when instance is deleted.

Default value: ``false``

##### <a name="automatic_instance_upgrades"></a>`automatic_instance_upgrades`

Data type: `Boolean`

Automatically upgrade the service control monitoring instance when a new version of servicecontrol is installed.

Default value: ``true``

### <a name="nservicebusservicecontrolmonitoring_instance"></a>`nservicebusservicecontrol::monitoring_instance`

Manages Service Control Monitoring Instances.

#### Parameters

The following parameters are available in the `nservicebusservicecontrol::monitoring_instance` defined type:

* [`ensure`](#ensure)
* [`instance_name`](#instance_name)
* [`install_path`](#install_path)
* [`log_path`](#log_path)
* [`instance_log_level`](#instance_log_level)
* [`host_name`](#host_name)
* [`port`](#port)
* [`error_queue`](#error_queue)
* [`transport`](#transport)
* [`display_name`](#display_name)
* [`connection_string`](#connection_string)
* [`description`](#description)
* [`service_account`](#service_account)
* [`service_account_password`](#service_account_password)
* [`service_restart_on_config_change`](#service_restart_on_config_change)
* [`service_manage`](#service_manage)
* [`skip_queue_creation`](#skip_queue_creation)
* [`remove_logs_on_delete`](#remove_logs_on_delete)
* [`automatic_instance_upgrades`](#automatic_instance_upgrades)

##### <a name="ensure"></a>`ensure`

Data type: `Enum['present', 'absent']`

Specifies whether the monitoring instance should exist.

##### <a name="instance_name"></a>`instance_name`

Data type: `String`

Specify the name of the ServiceControl Monitoring Instance (title).

Default value: `$title`

##### <a name="install_path"></a>`install_path`

Data type: `Stdlib::Absolutepath`

Specify the directory to use for this ServiceControl Monitoring Instance.

Default value: `"C:\\Program Files (x86)\\Particular Software\\${instance_name}"`

##### <a name="log_path"></a>`log_path`

Data type: `Stdlib::Absolutepath`

Specify the directory to use for this ServiceControl Monitoring Logs.

Default value: `"C:\\ProgramData\\Particular\\ServiceControl\\${instance_name}\\Logs"`

##### <a name="instance_log_level"></a>`instance_log_level`

Data type: `Nservicebusservicecontrol::Log_level`

Specify the level of logging that should be used in ServiceControl Monitoring logs.

Default value: `'Warn'`

##### <a name="host_name"></a>`host_name`

Data type: `Stdlib::Fqdn`

Specify the hostname to use in the URLACL.

Default value: `'localhost'`

##### <a name="port"></a>`port`

Data type: `Stdlib::Port`

Specify the port number to listen on. If this is the only ServiceControl Monitoring instance then 33633 is recommended.

Default value: `33633`

##### <a name="error_queue"></a>`error_queue`

Data type: `String`

Specify the ErrorQueue name.

Default value: `'error'`

##### <a name="transport"></a>`transport`

Data type: `Nservicebusservicecontrol::Transport`

Specify the NServiceBus Transport to use.

Default value: `'MSMQ'`

##### <a name="display_name"></a>`display_name`

Data type: `String`

Specify the Windows Service Display name. If unspecified the monitoring instance name will be used.

Default value: `$instance_name`

##### <a name="connection_string"></a>`connection_string`

Data type: `Optional[String]`

Specify the connection string to use to connect to the queuing system.

Default value: ``undef``

##### <a name="description"></a>`description`

Data type: `String`

Specify the description to use on the Windows Service for this instance.

Default value: `'A Monitoring Instance'`

##### <a name="service_account"></a>`service_account`

Data type: `String`

The Account to run the Windows service.

Default value: `'LocalSystem'`

##### <a name="service_account_password"></a>`service_account_password`

Data type: `Optional[String]`

The password for the ServiceAccount.

Default value: ``undef``

##### <a name="service_restart_on_config_change"></a>`service_restart_on_config_change`

Data type: `Boolean`

Specify if the servicecontrol monitoring instance's windows service should be restarted to pick up changes to its configuration file.

Default value: ``true``

##### <a name="service_manage"></a>`service_manage`

Data type: `Boolean`

Specifies whether or not to manage the desired state of the windows service for this instance.

Default value: ``true``

##### <a name="skip_queue_creation"></a>`skip_queue_creation`

Data type: `Boolean`

Normally an instance will attempt to create the queues that it uses. If this flag is set, queue creation will be skipped.

Default value: ``false``

##### <a name="remove_logs_on_delete"></a>`remove_logs_on_delete`

Data type: `Boolean`

Specifies if the service control logs should be deleted with the instance.

Default value: ``false``

##### <a name="automatic_instance_upgrades"></a>`automatic_instance_upgrades`

Data type: `Boolean`

Automatically upgrade the service control monitoring instance when a new version of servicecontrol is installed.

Default value: ``true``

## Data types

### <a name="nservicebusservicecontrollog_level"></a>`Nservicebusservicecontrol::Log_level`

The Nservicebusservicecontrol::Log_level data type.

Alias of

```puppet
Enum['Trace', 'Debug', 'Info', 'Warn', 'Error', 'Fatal', 'Off']
```

### <a name="nservicebusservicecontroltransport"></a>`Nservicebusservicecontrol::Transport`

https://github.com/Particular/ServiceControl/blob/develop/src/ServiceControlInstaller.Engine/Instances/TransportNames.cs

Alias of

```puppet
Enum['RabbitMQ - Conventional routing topology', 'SQL Server', 'MSMQ', 'Azure Storage Queue', 'Azure Service Bus', 'AmazonSQS']
```

## Tasks

### <a name="get_instances"></a>`get_instances`

Gets all servicecontrol instances.

**Supports noop?** false

## Plans

### <a name="nservicebusservicecontrolcompact_database"></a>`nservicebusservicecontrol::compact_database`

Compacts the servicecontrol instance's RavenDB Database.

#### Parameters

The following parameters are available in the `nservicebusservicecontrol::compact_database` plan:

* [`targets`](#targets)
* [`instance_name`](#instance_name)

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`

Targets to compact databases.

##### <a name="instance_name"></a>`instance_name`

Data type: `String[1]`

The name of the servicecontrol instance.

### <a name="nservicebusservicecontrolimport_failed_messages"></a>`nservicebusservicecontrol::import_failed_messages`

Imports failed error or audit messages.

#### Parameters

The following parameters are available in the `nservicebusservicecontrol::import_failed_messages` plan:

* [`targets`](#targets)
* [`instance_name`](#instance_name)
* [`instance_type`](#instance_type)

##### <a name="targets"></a>`targets`

Data type: `TargetSpec`

Targets to import failed messages on.

##### <a name="instance_name"></a>`instance_name`

Data type: `String[1]`

The name of the servicecontrol instance.

##### <a name="instance_type"></a>`instance_type`

Data type: `Enum['error', 'audit']`

The servicecontrol instance type (Audit or Error).

